@@ -1,5 +1,7 @@
-from .utils import *
+from .utils import getEndpointUrl
 from abstract_apis import asyncPostRequest
-def get_request(endpoint=None,**kwargs):
+import asyncio
+def callSolcatcherRpc(endpoint=None,**kwargs):
   url = getEndpointUrl(endpoint)
   return asyncio.run(asyncPostRequest(url=url,data=kwargs))
+  
